aboutsummaryrefslogtreecommitdiffstats
path: root/src/core/module/GlobalModuleContext.cpp
diff options
context:
space:
mode:
authorsaturneric <[email protected]>2024-07-28 15:07:15 +0000
committersaturneric <[email protected]>2024-07-28 15:07:15 +0000
commitadc5d89717cc1498c69792799c74ace413cca713 (patch)
tree698d46d2d36f95fcb74a6aa449ffcba1a4d5f637 /src/core/module/GlobalModuleContext.cpp
parentfix: can not import binary key data (diff)
downloadGpgFrontend-adc5d89717cc1498c69792799c74ace413cca713.tar.gz
GpgFrontend-adc5d89717cc1498c69792799c74ace413cca713.zip
fix: correct the spelling of 'deactivate'
Diffstat (limited to 'src/core/module/GlobalModuleContext.cpp')
-rw-r--r--src/core/module/GlobalModuleContext.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/core/module/GlobalModuleContext.cpp b/src/core/module/GlobalModuleContext.cpp
index 26c13a1b..c35e5229 100644
--- a/src/core/module/GlobalModuleContext.cpp
+++ b/src/core/module/GlobalModuleContext.cpp
@@ -197,8 +197,8 @@ class GlobalModuleContext::Impl {
}
auto module_info = module_info_opt.value();
- // activate the module if it is not already deactive.
- if (module_info->activate && (module_info->module->Deactive() == 0)) {
+ // activate the module if it is not already Deactivate.
+ if (module_info->activate && (module_info->module->Deactivate() == 0)) {
for (const auto& event_ids : module_info->listening_event_ids) {
auto& modules = module_events_table_[event_ids];
if (auto it = modules.find(module_id); it != modules.end()) {